@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es_ES">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
 <context>
     <name>About</name>
     <message>
@@ -26,7 +24,7 @@
 <context>
     <name>Footer</name>
     <message>
-        <location filename="../components/Footer.qml" line="171"/>
+        <location filename="../components/Footer.qml" line="180"/>
         <source>Recommended</source>
         <translation>Recomendado</translation>
     </message>
@@ -108,38 +106,38 @@
 <context>
     <name>MainView</name>
     <message>
-        <location filename="../components/MainView.qml" line="32"/>
-        <location filename="../components/MainView.qml" line="56"/>
+        <location filename="../components/MainView.qml" line="43"/>
+        <location filename="../components/MainView.qml" line="66"/>
         <source>Donate</source>
         <translation>Donar</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="49"/>
+        <location filename="../components/MainView.qml" line="59"/>
         <source>Preferences</source>
         <translation>Preferencias</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="63"/>
+        <location filename="../components/MainView.qml" line="73"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="70"/>
+        <location filename="../components/MainView.qml" line="80"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="77"/>
+        <location filename="../components/MainView.qml" line="87"/>
         <source>Quit</source>
         <translation>Salir</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="104"/>
+        <location filename="../components/MainView.qml" line="111"/>
         <source>Please donate!</source>
         <translation>¡Se agradece una donación!</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="118"/>
+        <location filename="../components/MainView.qml" line="125"/>
         <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
         <translation>Este servicio sólo se costea con donaciones de usuarias como tú. Mantener a flote la VPN cuesta unos 5 euros por persona y mes, pero cada contribución es valiosa. ¿Quieres hacer una donación?</translation>
     </message>
@@ -152,75 +150,85 @@
         <translation>Preferencias</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="54"/>
+        <location filename="../components/Preferences.qml" line="55"/>
         <source>Turn off the VPN to make changes</source>
         <translation>Desactiva la VPN para hacer cambios</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="69"/>
+        <location filename="../components/Preferences.qml" line="71"/>
         <source>Language</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="102"/>
+        <location filename="../components/Preferences.qml" line="105"/>
         <source>Censorship circumvention</source>
         <translation>Circumvención de censura</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="110"/>
+        <location filename="../components/Preferences.qml" line="113"/>
         <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
         <translation>Estas técnicas pueden evitar la censura, pero son más lentas. Actívalas sólo cuando lo necesites.</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="124"/>
+        <location filename="../components/Preferences.qml" line="127"/>
         <source>Use obfs4 bridges</source>
         <translation>Usar puentes obfs4</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="150"/>
+        <location filename="../components/Preferences.qml" line="153"/>
         <source>Traffic is obfuscated to bypass blocks</source>
         <translation>El tráfico será ofuscado para saltar bloqueos</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="164"/>
+        <location filename="../components/Preferences.qml" line="167"/>
         <source>Use Snowflake</source>
         <translation>Usar Snowflake</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="179"/>
+        <location filename="../components/Preferences.qml" line="182"/>
         <source>Snowflake needs Tor installed in your system</source>
         <translation>Snowflake necesita Tor instalado en el sistema</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="192"/>
+        <location filename="../components/Preferences.qml" line="195"/>
         <source>Transport</source>
         <translation>Transporte</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="200"/>
+        <location filename="../components/Preferences.qml" line="203"/>
         <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
         <translation>Con UDP la VPN puede ir más rápido. Podría estar bloqueado en algunas redes.</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="213"/>
+        <location filename="../components/Preferences.qml" line="216"/>
         <source>Use UDP if available</source>
         <translation>Usar UDP cuando se pueda</translation>
     </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="231"/>
+        <source>KCP might work when UDP is blocked on some networks.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="244"/>
+        <source>Use KCP if available</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Splash</name>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>There is a newer version available. </source>
         <translation>Hay disponible una versión nueva.</translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
         <translation>Asegúrate de &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;desinstalar&lt;/a&gt; la versión anterior antes de lanzar el nuevo instalador.</translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="104"/>
+        <location filename="../components/Splash.qml" line="105"/>
         <source>UPGRADE NOW</source>
         <translation>ACTUALIZAR AHORA</translation>
     </message>
@@ -228,9 +236,9 @@
 <context>
     <name>StatusBox</name>
     <message>
-        <location filename="../components/StatusBox.qml" line="91"/>
+        <location filename="../components/StatusBox.qml" line="78"/>
         <source>This can take several minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>Esto puede llevar varios minutos</translation>
     </message>
 </context>
 <context>
@@ -281,194 +289,175 @@
 <context>
     <name>VPNState</name>
     <message>
-        <location filename="../components/VPNState.qml" line="27"/>
+        <location filename="../components/VPNState.qml" line="26"/>
         <source>Setting up</source>
-        <translation type="unfinished"></translation>
+        <translation>Estableciendo</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="52"/>
-        <location filename="../components/VPNState.qml" line="156"/>
+        <location filename="../components/VPNState.qml" line="51"/>
+        <location filename="../components/VPNState.qml" line="153"/>
         <source>Connecting</source>
         <translation>Conectando</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="85"/>
+        <location filename="../components/VPNState.qml" line="82"/>
         <source>Unsecured
 Connection</source>
         <translation>Conexión
 Insegura</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="100"/>
-        <source>Turn on</source>
-        <translation>Activar</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="120"/>
+        <location filename="../components/VPNState.qml" line="117"/>
         <source>Secured
 Connection</source>
         <translation>Conexión
 Segura</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="135"/>
-        <source>Turn off</source>
-        <translation>Desactivar</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="172"/>
-        <source>Cancel</source>
-        <translation>Cancelar</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="256"/>
+        <location filename="../components/VPNState.qml" line="265"/>
         <source>%1 off</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 desconectada</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="256"/>
+        <location filename="../components/VPNState.qml" line="265"/>
         <source>off</source>
-        <translation>off</translation>
+        <translation>apagado</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="259"/>
+        <location filename="../components/VPNState.qml" line="268"/>
         <source>%1 on</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 on</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="262"/>
+        <location filename="../components/VPNState.qml" line="271"/>
         <source>Connecting to %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>Conectando a %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="265"/>
+        <location filename="../components/VPNState.qml" line="274"/>
         <source>Stopping %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>Deteniendo %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="268"/>
+        <location filename="../components/VPNState.qml" line="277"/>
         <source>%1 blocking internet</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 bloqueando Internet</translation>
     </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="276"/>
-        <source>pluggable transport connection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="278"/>
-        <source>connection done</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="280"/>
-        <source>doing handshake</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="282"/>
-        <source>handshake done</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../components/VPNState.qml" line="284"/>
-        <source>creating one-hop connection</source>
-        <translation type="unfinished"></translation>
+        <source>pluggable transport connection</source>
+        <translation>conexión de transporte conectable</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="286"/>
-        <source>requesting status</source>
-        <translation type="unfinished"></translation>
+        <source>connection done</source>
+        <translation>conexión realizada</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="288"/>
-        <source>loading status</source>
-        <translation type="unfinished"></translation>
+        <source>doing handshake</source>
+        <translation>haciendo negociación</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="290"/>
-        <source>loading keys</source>
-        <translation type="unfinished"></translation>
+        <source>handshake done</source>
+        <translation>negociación realizada</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="292"/>
-        <source>requesting descriptors</source>
-        <translation type="unfinished"></translation>
+        <source>creating one-hop connection</source>
+        <translation>creando conexión de un salto</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="294"/>
-        <source>loading descriptors</source>
-        <translation type="unfinished"></translation>
+        <source>requesting status</source>
+        <translation>solicitando estado</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="296"/>
-        <source>creating circuit</source>
-        <translation type="unfinished"></translation>
+        <source>loading status</source>
+        <translation>cargando estado</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="298"/>
+        <source>loading keys</source>
+        <translation>cargando claves</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="300"/>
+        <source>requesting descriptors</source>
+        <translation>solicitando descriptores</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="302"/>
+        <source>loading descriptors</source>
+        <translation>cargando descriptores</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="304"/>
+        <source>creating circuit</source>
+        <translation>creando circuito</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="306"/>
         <source>done</source>
-        <translation type="unfinished"></translation>
+        <translation>hecho</translation>
     </message>
 </context>
 <context>
     <name>VPNSwitch</name>
     <message>
         <location filename="../qml/VPNSwitch.qml" line="10"/>
-        <source></source>
-        <translation></translation>
+        <source/>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="144"/>
+        <location filename="../main.cpp" line="140"/>
         <source>: a fast and secure VPN. Powered by Bitmask.</source>
         <translation>: una VPN rápida y segura. Potenciada por Bitmask.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="151"/>
+        <location filename="../main.cpp" line="147"/>
         <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
         <translation>No mostrar el ícono en la bandeja del sistema (útil en conjunto con las extensiones de Intérprete de Comandos Gnome, o para controlar la VPN por otros medios).</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="158"/>
+        <location filename="../main.cpp" line="154"/>
         <source>Enable Web API.</source>
         <translation>Habilitar la Web API.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="164"/>
+        <location filename="../main.cpp" line="160"/>
         <source>Install helpers (Linux only, requires sudo).</source>
         <translation>Instalar programas auxiliares (sólo en Linux, requiere sudo).</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="170"/>
+        <location filename="../main.cpp" line="166"/>
         <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
         <translation>Usar obfs4 para ofuscar el tráfico, si está disponible con el proveedor.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="176"/>
+        <location filename="../main.cpp" line="172"/>
         <source>Enable autostart.</source>
-        <translation type="unfinished"></translation>
+        <translation>Habilitar autoarranque.</translation>
     </message>
     <message>
-        <source>Disable autostart for the next run.</source>
-        <translation type="vanished">Deshabilitar arranque automático para la siguiente ejecución.</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="181"/>
+        <location filename="../main.cpp" line="177"/>
         <source>Web API port (default: 8080)</source>
         <translation>Puerto para la API Web (por defecto: 8080)</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="184"/>
+        <location filename="../main.cpp" line="180"/>
         <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
         <translation>Iniciar la VPN, &apos;conectada&apos; o bien, &apos;desconectada&apos;.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
