@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="lt">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
 <context>
     <name>About</name>
     <message>
@@ -26,7 +24,7 @@
 <context>
     <name>Footer</name>
     <message>
-        <location filename="../components/Footer.qml" line="171"/>
+        <location filename="../components/Footer.qml" line="180"/>
         <source>Recommended</source>
         <translation>Rekomenduojama</translation>
     </message>
@@ -36,7 +34,7 @@
     <message>
         <location filename="../components/Help.qml" line="7"/>
         <source>Help</source>
-        <translation>Žinynas</translation>
+        <translation>Pagalba</translation>
     </message>
     <message>
         <location filename="../components/Help.qml" line="20"/>
@@ -108,38 +106,38 @@
 <context>
     <name>MainView</name>
     <message>
-        <location filename="../components/MainView.qml" line="32"/>
-        <location filename="../components/MainView.qml" line="56"/>
+        <location filename="../components/MainView.qml" line="43"/>
+        <location filename="../components/MainView.qml" line="66"/>
         <source>Donate</source>
         <translation>Paaukoti</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="49"/>
+        <location filename="../components/MainView.qml" line="59"/>
         <source>Preferences</source>
-        <translation>Nuostatos</translation>
+        <translation>Parinktys</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="63"/>
+        <location filename="../components/MainView.qml" line="73"/>
         <source>Help</source>
-        <translation>Žinynas</translation>
+        <translation>Pagalba</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="70"/>
+        <location filename="../components/MainView.qml" line="80"/>
         <source>About</source>
         <translation>Apie</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="77"/>
+        <location filename="../components/MainView.qml" line="87"/>
         <source>Quit</source>
-        <translation>Išeiti</translation>
+        <translation>Baigti</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="104"/>
+        <location filename="../components/MainView.qml" line="111"/>
         <source>Please donate!</source>
         <translation>Prašome paaukoti!</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="118"/>
+        <location filename="../components/MainView.qml" line="125"/>
         <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
         <translation>Ši paslauga yra pilnai apmokama iš lėšų, kurias paaukoja tokie naudotojai, kaip jūs. VPN aptarnavimo kaina vienam žmogui siekia maždaug 5 JAV dolerius per mėnesį, bet yra vertinamas kiekvienas centas. Ar norite paaukoti dabar?</translation>
     </message>
@@ -149,78 +147,88 @@
     <message>
         <location filename="../components/Preferences.qml" line="11"/>
         <source>Preferences</source>
-        <translation>Nuostatos</translation>
+        <translation>Parinktys</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="54"/>
+        <location filename="../components/Preferences.qml" line="55"/>
         <source>Turn off the VPN to make changes</source>
         <translation>Norėdami atlikti pakeitimus, išjunkite VPN</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="69"/>
+        <location filename="../components/Preferences.qml" line="71"/>
         <source>Language</source>
-        <translation type="unfinished"></translation>
+        <translation>Kalba</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="102"/>
+        <location filename="../components/Preferences.qml" line="105"/>
         <source>Censorship circumvention</source>
         <translation>Cenzūros apėjimas</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="110"/>
+        <location filename="../components/Preferences.qml" line="113"/>
         <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
         <translation>Šios technikos gali apeiti cenzūrą, bet yra lėtesnės. Naudokite jas tik tada, kai prireikia.</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="124"/>
+        <location filename="../components/Preferences.qml" line="127"/>
         <source>Use obfs4 bridges</source>
         <translation>Naudoti obfs4 tinklų tiltus</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="150"/>
+        <location filename="../components/Preferences.qml" line="153"/>
         <source>Traffic is obfuscated to bypass blocks</source>
         <translation>Duomenų srautas yra maskuojamas, kad būtų apeiti blokavimai</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="164"/>
+        <location filename="../components/Preferences.qml" line="167"/>
         <source>Use Snowflake</source>
-        <translation>Naudoti „Snowflake“</translation>
+        <translation>Naudoti Snowflake</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="179"/>
+        <location filename="../components/Preferences.qml" line="182"/>
         <source>Snowflake needs Tor installed in your system</source>
         <translation>„Snowflake“ reikalauja, kad jūsų sistemoje būtų įdiegtas „Tor“</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="192"/>
+        <location filename="../components/Preferences.qml" line="195"/>
         <source>Transport</source>
         <translation>Perdavimas</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="200"/>
+        <location filename="../components/Preferences.qml" line="203"/>
         <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
         <translation>UDP gali padaryti VPN greitesnį. UDP kai kuriuose tinkluose gali būti blokuojamas.</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="213"/>
+        <location filename="../components/Preferences.qml" line="216"/>
         <source>Use UDP if available</source>
         <translation>Jei prieinama, naudoti UDP</translation>
     </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="231"/>
+        <source>KCP might work when UDP is blocked on some networks.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="244"/>
+        <source>Use KCP if available</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Splash</name>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>There is a newer version available. </source>
         <translation>Yra prieinama naujesnė versija.</translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
         <translation>Prieš paleisdami diegimo programą, įsitikinkite, kad &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;pašalinote&lt;/a&gt; ankstesnę versiją.</translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="104"/>
+        <location filename="../components/Splash.qml" line="105"/>
         <source>UPGRADE NOW</source>
         <translation>NAUJINTI DABAR</translation>
     </message>
@@ -228,9 +236,9 @@
 <context>
     <name>StatusBox</name>
     <message>
-        <location filename="../components/StatusBox.qml" line="91"/>
+        <location filename="../components/StatusBox.qml" line="78"/>
         <source>This can take several minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>Tai gali užtrukti keletą minučių</translation>
     </message>
 </context>
 <context>
@@ -260,7 +268,7 @@
         <location filename="../components/Systray.qml" line="57"/>
         <source>Quit</source>
         <extracomment>Part of the systray menu; quits the application</extracomment>
-        <translation>Išeiti</translation>
+        <translation>Baigti</translation>
     </message>
     <message>
         <location filename="../components/Systray.qml" line="74"/>
@@ -281,194 +289,175 @@
 <context>
     <name>VPNState</name>
     <message>
-        <location filename="../components/VPNState.qml" line="27"/>
+        <location filename="../components/VPNState.qml" line="26"/>
         <source>Setting up</source>
-        <translation type="unfinished"></translation>
+        <translation>Nustatoma</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="52"/>
-        <location filename="../components/VPNState.qml" line="156"/>
+        <location filename="../components/VPNState.qml" line="51"/>
+        <location filename="../components/VPNState.qml" line="153"/>
         <source>Connecting</source>
         <translation>Jungiamasi</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="85"/>
+        <location filename="../components/VPNState.qml" line="82"/>
         <source>Unsecured
 Connection</source>
         <translation>Neapsaugotas
 ryšys</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="100"/>
-        <source>Turn on</source>
-        <translation>Įjungti</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="120"/>
+        <location filename="../components/VPNState.qml" line="117"/>
         <source>Secured
 Connection</source>
         <translation>Apsaugotas
 ryšys</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="135"/>
-        <source>Turn off</source>
-        <translation>Išjungti</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="172"/>
-        <source>Cancel</source>
-        <translation>Atsisakyti</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="256"/>
+        <location filename="../components/VPNState.qml" line="265"/>
         <source>%1 off</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 išjungta</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="256"/>
+        <location filename="../components/VPNState.qml" line="265"/>
         <source>off</source>
         <translation>išjungta</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="259"/>
+        <location filename="../components/VPNState.qml" line="268"/>
         <source>%1 on</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 įjungta</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="262"/>
+        <location filename="../components/VPNState.qml" line="271"/>
         <source>Connecting to %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>Jungiamasi prie %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="265"/>
+        <location filename="../components/VPNState.qml" line="274"/>
         <source>Stopping %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>Stabdoma %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="268"/>
+        <location filename="../components/VPNState.qml" line="277"/>
         <source>%1 blocking internet</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 blokuoja internetą</translation>
     </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="276"/>
-        <source>pluggable transport connection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="278"/>
-        <source>connection done</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="280"/>
-        <source>doing handshake</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="282"/>
-        <source>handshake done</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../components/VPNState.qml" line="284"/>
-        <source>creating one-hop connection</source>
-        <translation type="unfinished"></translation>
+        <source>pluggable transport connection</source>
+        <translation>keičiamojo perdavimo ryšys</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="286"/>
-        <source>requesting status</source>
-        <translation type="unfinished"></translation>
+        <source>connection done</source>
+        <translation>ryšys atliktas</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="288"/>
-        <source>loading status</source>
-        <translation type="unfinished"></translation>
+        <source>doing handshake</source>
+        <translation>atliekamas išankstinis suderinimas</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="290"/>
-        <source>loading keys</source>
-        <translation type="unfinished"></translation>
+        <source>handshake done</source>
+        <translation>išankstinis suderinimas atliktas</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="292"/>
-        <source>requesting descriptors</source>
-        <translation type="unfinished"></translation>
+        <source>creating one-hop connection</source>
+        <translation>kuriamas vieno šuolio ryšys</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="294"/>
-        <source>loading descriptors</source>
-        <translation type="unfinished"></translation>
+        <source>requesting status</source>
+        <translation>užklausimo būsena</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="296"/>
-        <source>creating circuit</source>
-        <translation type="unfinished"></translation>
+        <source>loading status</source>
+        <translation>įkėlimo būsena</translation>
     </message>
     <message>
         <location filename="../components/VPNState.qml" line="298"/>
+        <source>loading keys</source>
+        <translation>įkeliami raktai</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="300"/>
+        <source>requesting descriptors</source>
+        <translation>užklausiami deskriptoriai</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="302"/>
+        <source>loading descriptors</source>
+        <translation>įkeliami deskriptoriai</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="304"/>
+        <source>creating circuit</source>
+        <translation>kuriama grandinė</translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="306"/>
         <source>done</source>
-        <translation type="unfinished"></translation>
+        <translation>atlikta</translation>
     </message>
 </context>
 <context>
     <name>VPNSwitch</name>
     <message>
         <location filename="../qml/VPNSwitch.qml" line="10"/>
-        <source></source>
-        <translation></translation>
+        <source/>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="144"/>
+        <location filename="../main.cpp" line="140"/>
         <source>: a fast and secure VPN. Powered by Bitmask.</source>
         <translation>: greitas ir saugus VPN. Veikia su Bitmask.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="151"/>
+        <location filename="../main.cpp" line="147"/>
         <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
         <translation>Nerodyti sistemos dėklo piktogramos (praverčia su Gnome apvalkalo plėtiniu arba siekiant kitokiu būdu valdyti VPN).</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="158"/>
+        <location filename="../main.cpp" line="154"/>
         <source>Enable Web API.</source>
         <translation>Įjungti saityno API.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="164"/>
+        <location filename="../main.cpp" line="160"/>
         <source>Install helpers (Linux only, requires sudo).</source>
         <translation>Įdiegti pagelbiklius (tik Linux, reikalauja sudo).</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="170"/>
+        <location filename="../main.cpp" line="166"/>
         <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
         <translation>Naudoti obfs4, siekiant maskuoti duomenų srautą, jei prieinama iš teikėjo.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="176"/>
+        <location filename="../main.cpp" line="172"/>
         <source>Enable autostart.</source>
-        <translation type="unfinished"></translation>
+        <translation>Įjungti automatinį paleidimą.</translation>
     </message>
     <message>
-        <source>Disable autostart for the next run.</source>
-        <translation type="vanished">Išjungti automatinį paleidimą kitam paleidimui.</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="181"/>
+        <location filename="../main.cpp" line="177"/>
         <source>Web API port (default: 8080)</source>
         <translation>Saityno API prievadas (numatytasis: 8080)</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="184"/>
+        <location filename="../main.cpp" line="180"/>
         <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
         <translation>Paleisti VPN, arba „on“, arba „off“.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
