@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh">
 <context>
     <name>About</name>
     <message>
@@ -26,7 +24,7 @@
 <context>
     <name>Footer</name>
     <message>
-        <location filename="../components/Footer.qml" line="171"/>
+        <location filename="../components/Footer.qml" line="180"/>
         <source>Recommended</source>
         <translation>推荐</translation>
     </message>
@@ -108,38 +106,38 @@
 <context>
     <name>MainView</name>
     <message>
-        <location filename="../components/MainView.qml" line="32"/>
-        <location filename="../components/MainView.qml" line="56"/>
+        <location filename="../components/MainView.qml" line="43"/>
+        <location filename="../components/MainView.qml" line="66"/>
         <source>Donate</source>
         <translation>捐助</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="49"/>
+        <location filename="../components/MainView.qml" line="59"/>
         <source>Preferences</source>
         <translation>首选项</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="63"/>
+        <location filename="../components/MainView.qml" line="73"/>
         <source>Help</source>
         <translation>帮助</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="70"/>
+        <location filename="../components/MainView.qml" line="80"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="77"/>
+        <location filename="../components/MainView.qml" line="87"/>
         <source>Quit</source>
         <translation>退出</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="104"/>
+        <location filename="../components/MainView.qml" line="111"/>
         <source>Please donate!</source>
         <translation>请捐助！</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="118"/>
+        <location filename="../components/MainView.qml" line="125"/>
         <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
         <translation>此服务的费用完全由像您一样的用户捐助支付。VPN 的运营成本大约为每人每月 5 美元，开销须精打细算。您是否立刻捐助此服务？</translation>
     </message>
@@ -152,75 +150,85 @@
         <translation>首选项</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="54"/>
+        <location filename="../components/Preferences.qml" line="55"/>
         <source>Turn off the VPN to make changes</source>
         <translation>关闭 VPN 进行更改</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="69"/>
+        <location filename="../components/Preferences.qml" line="71"/>
         <source>Language</source>
         <translation>语言</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="102"/>
+        <location filename="../components/Preferences.qml" line="105"/>
         <source>Censorship circumvention</source>
         <translation>审查规避</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="110"/>
+        <location filename="../components/Preferences.qml" line="113"/>
         <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
         <translation>该技术可规避审查，但速度较慢，请仅在需要时使用。</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="124"/>
+        <location filename="../components/Preferences.qml" line="127"/>
         <source>Use obfs4 bridges</source>
         <translation>使用 Obfs4 网桥</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="150"/>
+        <location filename="../components/Preferences.qml" line="153"/>
         <source>Traffic is obfuscated to bypass blocks</source>
         <translation>对通信进行混淆以规避屏蔽</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="164"/>
+        <location filename="../components/Preferences.qml" line="167"/>
         <source>Use Snowflake</source>
         <translation>使用 Snowflake</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="179"/>
+        <location filename="../components/Preferences.qml" line="182"/>
         <source>Snowflake needs Tor installed in your system</source>
         <translation>Snowflake 需要在系统上安装 Tor</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="192"/>
+        <location filename="../components/Preferences.qml" line="195"/>
         <source>Transport</source>
         <translation>传输</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="200"/>
+        <location filename="../components/Preferences.qml" line="203"/>
         <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
         <translation>UDP 可令 VPN 更快，但是可能在某些网络上被屏蔽。</translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="213"/>
+        <location filename="../components/Preferences.qml" line="216"/>
         <source>Use UDP if available</source>
         <translation>可用时使用 UDP</translation>
     </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="231"/>
+        <source>KCP might work when UDP is blocked on some networks.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="244"/>
+        <source>Use KCP if available</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Splash</name>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>There is a newer version available. </source>
         <translation>有较新版本可用。</translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
         <translation>在运行新的安装程序之前，请确保&lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;卸载&lt;/a&gt;之前的版本。</translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="104"/>
+        <location filename="../components/Splash.qml" line="105"/>
         <source>UPGRADE NOW</source>
         <translation>立刻升级</translation>
     </message>
@@ -228,7 +236,7 @@
 <context>
     <name>StatusBox</name>
     <message>
-        <location filename="../components/StatusBox.qml" line="91"/>
+        <location filename="../components/StatusBox.qml" line="78"/>
         <source>This can take several minutes</source>
         <translation>这可能会花几分钟</translation>
     </message>
@@ -281,137 +289,122 @@
 <context>
     <name>VPNState</name>
     <message>
-        <location filename="../components/VPNState.qml" line="27"/>
+        <location filename="../components/VPNState.qml" line="26"/>
         <source>Setting up</source>
         <translation>准备中</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="52"/>
-        <location filename="../components/VPNState.qml" line="156"/>
+        <location filename="../components/VPNState.qml" line="51"/>
+        <location filename="../components/VPNState.qml" line="153"/>
         <source>Connecting</source>
         <translation>正在连接</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="85"/>
+        <location filename="../components/VPNState.qml" line="82"/>
         <source>Unsecured
 Connection</source>
         <translation>不安全
 连接</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="100"/>
-        <source>Turn on</source>
-        <translation>开启</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="120"/>
+        <location filename="../components/VPNState.qml" line="117"/>
         <source>Secured
 Connection</source>
         <translation>安全
 连接</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="135"/>
-        <source>Turn off</source>
-        <translation>关闭</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="172"/>
-        <source>Cancel</source>
-        <translation>取消</translation>
-    </message>
-    <message>
-        <location filename="../components/VPNState.qml" line="256"/>
+        <location filename="../components/VPNState.qml" line="265"/>
         <source>%1 off</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 关闭</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="256"/>
+        <location filename="../components/VPNState.qml" line="265"/>
         <source>off</source>
         <translation>关闭</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="259"/>
+        <location filename="../components/VPNState.qml" line="268"/>
         <source>%1 on</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 开启</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="262"/>
+        <location filename="../components/VPNState.qml" line="271"/>
         <source>Connecting to %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>正在连接至 %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="265"/>
+        <location filename="../components/VPNState.qml" line="274"/>
         <source>Stopping %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>正在停止 %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="268"/>
+        <location filename="../components/VPNState.qml" line="277"/>
         <source>%1 blocking internet</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 正在屏蔽互联网</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="276"/>
+        <location filename="../components/VPNState.qml" line="284"/>
         <source>pluggable transport connection</source>
         <translation>可插拔传输连接</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="278"/>
+        <location filename="../components/VPNState.qml" line="286"/>
         <source>connection done</source>
         <translation>连接完成</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="280"/>
+        <location filename="../components/VPNState.qml" line="288"/>
         <source>doing handshake</source>
         <translation>正在握手</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="282"/>
+        <location filename="../components/VPNState.qml" line="290"/>
         <source>handshake done</source>
         <translation>握手完成</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="284"/>
+        <location filename="../components/VPNState.qml" line="292"/>
         <source>creating one-hop connection</source>
         <translation>正在建立单跳连接</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="286"/>
+        <location filename="../components/VPNState.qml" line="294"/>
         <source>requesting status</source>
         <translation>正在请求状态</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="288"/>
+        <location filename="../components/VPNState.qml" line="296"/>
         <source>loading status</source>
         <translation>正在加载状态</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="290"/>
+        <location filename="../components/VPNState.qml" line="298"/>
         <source>loading keys</source>
         <translation>正在加载密钥</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="292"/>
+        <location filename="../components/VPNState.qml" line="300"/>
         <source>requesting descriptors</source>
         <translation>正在请求描述符</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="294"/>
+        <location filename="../components/VPNState.qml" line="302"/>
         <source>loading descriptors</source>
         <translation>正在加载描述符</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="296"/>
+        <location filename="../components/VPNState.qml" line="304"/>
         <source>creating circuit</source>
         <translation>正在建立链路</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="298"/>
+        <location filename="../components/VPNState.qml" line="306"/>
         <source>done</source>
         <translation>完成</translation>
     </message>
@@ -420,51 +413,51 @@ Connection</source>
     <name>VPNSwitch</name>
     <message>
         <location filename="../qml/VPNSwitch.qml" line="10"/>
-        <source></source>
-        <translation></translation>
+        <source/>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="144"/>
+        <location filename="../main.cpp" line="140"/>
         <source>: a fast and secure VPN. Powered by Bitmask.</source>
         <translation>：快速安全的 VPN。由 Bitmask 提供技术支持。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="151"/>
+        <location filename="../main.cpp" line="147"/>
         <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
         <translation>不显示系统托盘图标（与 Gnome Shell 扩展一起使用时很有用，或用于通过其他方式控制 VPN）。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="158"/>
+        <location filename="../main.cpp" line="154"/>
         <source>Enable Web API.</source>
         <translation>启用 Web API。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="164"/>
+        <location filename="../main.cpp" line="160"/>
         <source>Install helpers (Linux only, requires sudo).</source>
         <translation>安装帮助程序（仅限 Linux，需使用 sudo）。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="170"/>
+        <location filename="../main.cpp" line="166"/>
         <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
         <translation>使用 obfs4 混淆通信（如果提供商提供）。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="176"/>
+        <location filename="../main.cpp" line="172"/>
         <source>Enable autostart.</source>
         <translation>启用自启动。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="181"/>
+        <location filename="../main.cpp" line="177"/>
         <source>Web API port (default: 8080)</source>
         <translation>Web API 端口（默认：8080）</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="184"/>
+        <location filename="../main.cpp" line="180"/>
         <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
         <translation>启动 VPN，“开启”或“关闭”。</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
